<?php

namespace FiloBlu\Cegid\Setup;

use Magento\Framework\DB\Adapter\AdapterInterface;
use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Zend_Db_Exception;

/**
 * Class InstallSchema
 * @package FiloBlu\Cegid\Setup
 */
class InstallSchema implements InstallSchemaInterface
{
    /**
     * {@inheritdoc}
     * @throws Zend_Db_Exception
     */
    public function install(
        SchemaSetupInterface $setup,
        ModuleContextInterface $context
    )
    {
        $setup->startSetup();
        $this->createSellerTable($setup);
        $this->addQuoteExtensionTable($setup);
        $setup->endSetup();
    }

    /**
     * @param SchemaSetupInterface $setup
     * @throws Zend_Db_Exception
     */
    public function createSellerTable(SchemaSetupInterface $setup)
    {
        $tableName = $setup->getTable('filoblu_cegid_seller');

        if ($setup->tableExists($tableName)) {
            return;
        }

        $table = $setup->getConnection()->newTable($tableName);
        $table
            ->addColumn(
                'meta_id',
                Table::TYPE_INTEGER,
                null,
                ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
                'flow_channels'
            )
            ->addColumn(
                'cegid_id',
                Table::TYPE_TEXT,
                255,
                [],
                'Cegid id'
            )
            ->addIndex(
                $setup->getIdxName($table->getName(), ['cegid_id']),
                ['cegid_id'],
                AdapterInterface::INDEX_TYPE_UNIQUE
            )
            ->addColumn(
                'nickname',
                Table::TYPE_TEXT,
                255,
                [],
                'Seller nickname'
            )
            ->addColumn(
                'shop_code',
                Table::TYPE_TEXT,
                255,
                [],
                'Shop code'
            )
            ->addColumn(
                'meta_ref_id',
                Table::TYPE_INTEGER,
                '11',
                [],
                'meta_ref_id'
            )
            ->addColumn(
                'meta_file',
                Table::TYPE_INTEGER,
                null,
                [],
                'meta_file'
            )
            ->addColumn(
                'meta_processed',
                Table::TYPE_INTEGER,
                null,
                [],
                'meta_processed'
            )
            ->addColumn(
                'meta_insert_time',
                Table::TYPE_DATETIME,
                null,
                ['unsigned' => true, 'nullable' => false],
                'meta_insert_time'
            )
            ->addColumn(
                'meta_process_time',
                Table::TYPE_DATETIME,
                null,
                [],
                'meta_process_time'
            );
        $setup->getConnection()->createTable($table);
    }

    /**
     * @param SchemaSetupInterface $setup
     * @throws Zend_Db_Exception
     */
    public function addQuoteExtensionTable(SchemaSetupInterface $setup)
    {
        $tableName = $setup->getTable('filoblu_cegid_quote_extension');
        if ($setup->tableExists($tableName)) {
            return;
        }
        $table = $setup->getConnection()->newTable($tableName);
        $table->addColumn('quote_id',
            Table::TYPE_INTEGER,
            null,
            ['unsigned' => true, 'nullable' => false],
            'Quote ID')
            ->addColumn(
                'seller_id',
                Table::TYPE_TEXT,
                255,
                [],
                'Cegid id'
            )
            ->addIndex(
                $setup->getIdxName($table->getName(), ['seller_id']),
                ['seller_id'],
                AdapterInterface::INDEX_TYPE_INDEX
            )
            ->addForeignKey(
                $setup->getFkName($table->getName(), 'quote_id', 'quote', 'entity_id'),
                'quote_id',
                $setup->getTable('quote'),
                'entity_id',
                Table::ACTION_CASCADE
            );
        $setup->getConnection()->createTable($table);
    }
}
